@@ -38,10 +38,14 @@ class IdentityToken:
 
     def is_validly_signed(
         self,
+        audience: str,
         key_cache: Optional[KeyCache] = None,
         ignore_expiry: bool = False
     ) -> bool:
 
+        if not isinstance(audience, str):
+            raise TypeError('audience must be of type `str`')
+
         apple_public_key = self._header.retrieve_public_key(key_cache)
         rsa_key = apple_public_key.rsa_public_key
         pks = rsa_key.save_pkcs1()
@@ -50,14 +54,13 @@ class IdentityToken:
             result = jwt.decode(
                 jwt=self._raw_token,
                 key=pks,
-                verify=True,
                 algorithms=['RS256'],
-                audience='blinkybeach.Makara',
+                audience=audience,
                 options={
                     'verify_exp': not ignore_expiry
                 }
             )
-        except PyJWTError:
+        except PyJWTError as error:
             return False
 
         return result is not None
